@@ -54,8 +54,9 @@ def decrypt(password, data):
     string you can re-create that using `result.decode('utf8')`.
     '''
     _assert_not_string(data)
+    _assert_header_sc(data)
+    _assert_header_version(data)
     _assert_decrypt_length(data)
-    _assert_header(data)
     raw = data[len(HEADER):]
     salt = raw[:SALT_LEN//8]
     hmac_key, cipher_key = _expand_keys(password, salt)
@@ -86,10 +87,12 @@ def _assert_decrypt_length(data):
     if len(data) < len(HEADER) + SALT_LEN//8 + HASH.digest_size:
         raise DecryptionException('Missing data.')
     
-def _assert_header(data):
-    if data[:2] != HEADER[:2]:
+def _assert_header_sc(data):
+    if len(data) < 2 or data[:2] != HEADER[:2]:
         raise DecryptionException('Data passed to decrypt were not generated by simple-crypt (bad header).')
-    if data[:len(HEADER)] != HEADER:
+
+def _assert_header_version(data):
+    if len(data) < len(HEADER) or data[:len(HEADER)] != HEADER:
         raise DecryptionException('The data appear to be encrypted with a more recent version of simple-crypt (bad header). ' +
         'Please update the library and try again.')
 
